import React from 'react';
import { useTranslation, initReactI18next } from 'react-i18next';
import i18n from 'i18next';
import LanguageDetector from 'i18next-browser-languagedetector';
import './form.css';
import './style.css';

import translations from './translations.json';

i18n
  .use(LanguageDetector)
  .use(initReactI18next)
  .init({
    fallbackLng: 'en',
    resources: translations,
  });

const MultiLanguageComponent = () => {
  const { t, i18n } = useTranslation();

  const changeLanguage = (lng) => {
    i18n.changeLanguage(lng);
  };

  return (
    <div className="phppot-container">
      <div className="textline">
        <span>Select language:</span>
        <a onClick={() => changeLanguage('en')} style={{ fontWeight: i18n.language === 'en' ? 'bold' : 'normal' }}>
          en
        </a>
        <a onClick={() => changeLanguage('es')} style={{ fontWeight: i18n.language === 'es' ? 'bold' : 'normal' }}>
          es
        </a>
        <a onClick={() => changeLanguage('de')} style={{ fontWeight: i18n.language === 'de' ? 'bold' : 'normal' }}>
          de
        </a>
      </div>
      <h1>{t('heading')}</h1>

      <p>{t('text')}</p>
      <div className="text">
        <p>{t('Text')}</p>
      </div>
    </div>
  );
};

export default MultiLanguageComponent;
